==> knative-model-5.2.1-sources.jar: annotations/io/fabric8/knative/serving/v1beta1/RevisionBuilder.java <==
package io.fabric8.knative.serving.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class RevisionBuilder extends io.fabric8.knative.serving.v1beta1.RevisionFluentImpl<io.fabric8.knative.serving.v1beta1.RevisionBuilder> implements VisitableBuilder<io.fabric8.knative.serving.v1beta1.Revision,io.fabric8.knative.serving.v1beta1.RevisionBuilder> {

    io.fabric8.knative.serving.v1beta1.RevisionFluent<?> fluent;
    Boolean validationEnabled;

    public RevisionBuilder() {
        this(true);
    }

    public RevisionBuilder(Boolean validationEnabled) {
        this(new Revision(), validationEnabled);
    }

    public RevisionBuilder(io.fabric8.knative.serving.v1beta1.RevisionFluent<?> fluent) {
        this(fluent, true);
    }

    public RevisionBuilder(io.fabric8.knative.serving.v1beta1.RevisionFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new Revision(), validationEnabled);
    }

    public RevisionBuilder(io.fabric8.knative.serving.v1beta1.RevisionFluent<?> fluent,io.fabric8.knative.serving.v1beta1.Revision instance) {
        this(fluent, instance, true);
    }

    public RevisionBuilder(io.fabric8.knative.serving.v1beta1.RevisionFluent<?> fluent,io.fabric8.knative.serving.v1beta1.Revision instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withApiVersion(instance.getApiVersion()); 
        fluent.withKind(instance.getKind()); 
        fluent.withMetadata(instance.getMetadata()); 
        fluent.withSpec(instance.getSpec()); 
        fluent.withStatus(instance.getStatus()); 
        this.validationEnabled = validationEnabled; 
    }

    public RevisionBuilder(io.fabric8.knative.serving.v1beta1.Revision instance) {
        this(instance,true);
    }

    public RevisionBuilder(io.fabric8.knative.serving.v1beta1.Revision instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withApiVersion(instance.getApiVersion()); 
        this.withKind(instance.getKind()); 
        this.withMetadata(instance.getMetadata()); 
        this.withSpec(instance.getSpec()); 
        this.withStatus(instance.getStatus()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.knative.serving.v1beta1.EditableRevision build() {
        EditableRevision buildable = new EditableRevision(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        RevisionBuilder that = (RevisionBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> knative-model-5.3.1-sources.jar: annotations/io/fabric8/knative/serving/v1beta1/RevisionBuilder.java <==
package io.fabric8.knative.serving.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class RevisionBuilder extends io.fabric8.knative.serving.v1beta1.RevisionFluentImpl<io.fabric8.knative.serving.v1beta1.RevisionBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.knative.serving.v1beta1.Revision,io.fabric8.knative.serving.v1beta1.RevisionBuilder> {

    io.fabric8.knative.serving.v1beta1.RevisionFluent<?> fluent;
    Boolean validationEnabled;

    public RevisionBuilder() {
        this(true);
    }

    public RevisionBuilder(Boolean validationEnabled) {
        this(new Revision(), validationEnabled);
    }

    public RevisionBuilder(io.fabric8.knative.serving.v1beta1.RevisionFluent<?> fluent) {
        this(fluent, true);
    }

    public RevisionBuilder(io.fabric8.knative.serving.v1beta1.RevisionFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new Revision(), validationEnabled);
    }

    public RevisionBuilder(io.fabric8.knative.serving.v1beta1.RevisionFluent<?> fluent,io.fabric8.knative.serving.v1beta1.Revision instance) {
        this(fluent, instance, true);
    }

    public RevisionBuilder(io.fabric8.knative.serving.v1beta1.RevisionFluent<?> fluent,io.fabric8.knative.serving.v1beta1.Revision instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withApiVersion(instance.getApiVersion()); 
        fluent.withKind(instance.getKind()); 
        fluent.withMetadata(instance.getMetadata()); 
        fluent.withSpec(instance.getSpec()); 
        fluent.withStatus(instance.getStatus()); 
        this.validationEnabled = validationEnabled; 
    }

    public RevisionBuilder(io.fabric8.knative.serving.v1beta1.Revision instance) {
        this(instance,true);
    }

    public RevisionBuilder(io.fabric8.knative.serving.v1beta1.Revision instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withApiVersion(instance.getApiVersion()); 
        this.withKind(instance.getKind()); 
        this.withMetadata(instance.getMetadata()); 
        this.withSpec(instance.getSpec()); 
        this.withStatus(instance.getStatus()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.knative.serving.v1beta1.EditableRevision build() {
        EditableRevision buildable = new EditableRevision(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        RevisionBuilder that = (RevisionBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
